#
# spec file for package mmv
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mmv
Version:        2.10
Release:        1.1
Summary:        Move/Copy/Append/Link Multiple Files by Wildcard Patterns
License:        GPL-1.0-or-later
Group:          Productivity/File utilities
URL:            https://github.com/rrthomas/mmv/
Source:         https://github.com/rrthomas/mmv/releases/download/v%{version}/mmv-%{version}.tar.gz
BuildRequires:  c_compiler
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bdw-gc)

%description
Mmv moves (or copies, appends, or links, as specified) each source file matching
a from pattern to the target name specified by the to pattern.  This multiple
action is performed safely, i.e. without any unexpected deletion of files due to
collisions of target names with existing filenames or with other target names.
Furthermore, before doing anything, mmv attempts to detect any errors that would
result from the entire set of actions specified and gives the user the choice of
either proceeding by avoiding the offending parts or aborting.

%prep
%autosetup

%build
%configure --docdir="%{_defaultdocdir}/%{name}"
%make_build

%install
%make_install
cp -a COPYING "%{buildroot}/%{_defaultdocdir}/%{name}/"

%files
%{_defaultdocdir}/%{name}/
%{_bindir}/mad
%{_bindir}/mcp
%{_bindir}/mln
%{_bindir}/mmv
%{_mandir}/man1/mad.1%{?ext_man}
%{_mandir}/man1/mcp.1%{?ext_man}
%{_mandir}/man1/mln.1%{?ext_man}
%{_mandir}/man1/mmv.1%{?ext_man}

%changelog
* Sat Feb  8 2025 Dirk Müller <dmueller@suse.com>
- update to 2.10:
  * This release adds a ‘c’ flag for output patterns that
    capitalizes words in the output name, similar to ‘u’ and ‘l’
    for upper and lower casing.
- update to 2.9.1:
  * The previous release shipped with a broken man page; this
    release is just a rebuild. Thanks to the user who promptly
    notified me of the problem!
- update to 2.9:
  * This release make the --rename mode work the same as the
    default --move, since we can now rename directories freely in
    any case. The --rename flag is no longer documented, but is
    still accepted by mmv for backwards compatibility.
  * Some code that previously tried to drop privileges for most
    but not all uses was removed, as it served no useful purpose,
    and triggered static analysis tools that diagnosed a security
    flaw (setuid without setgroups). mmv is really just a fancy
    version of mv/cp/ln, which do not drop privileges; this
    behaviour was neither expected nor desired.
- update to 2.8:
  * This release fixes moving directories into newly-created
    directories. Previously, mmv tried erroneously to copy then
    move the directory rather than simply rename it.
  * Also, when a target directory is missing, mmv will now
    suggest using --makedirs.
  * This release also adds symlinks to the man page mmv(1) under
    mmv’s other executable names.
- update to 2.7:
  * This release removes the use of libgc, which was fragile,
    relying on build system shenanigans, and is not that useful
    in a one-shot tool.
* Sat Jul  6 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 2.6:
  * This release re-adds the “mad” (“append”) command, and fixes how
    the program name is checked when deciding which mode to run in.
  * There is also a build system fix.
* Thu Dec 28 2023 Dirk Müller <dmueller@suse.com>
- update to 2.5.1:
  * This release fixes a crash introduced in 2.5, which seems to
    be related to an unneeded update of gnulib. Hence, this
    release simply reverts to the previous version of gnulib.
- update to 2.5:
  * This release stops mmv trying to copy a directory into
    itself.
* Fri Jun 23 2023 pgajdos@suse.com
- version update to 2.4
  * no upstream changelog, see
  * https://github.com/rrthomas/mmv/commits/master
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.3
  * Lift restriction that mmv could not work on directories
    (except with -r)
  * Remove the ability to read output back on standard input
- Delete allow-non-ascii.patch, mmv-1.01b-include.dif,
  mmv-1.01b-options.patch, mmv-1.01b.dif (no longer applicable)
* Sun Jul 12 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
* Fri Sep 30 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Sat Feb  5 2011 asterios.dramis@gmail.com
- Use as source package the one from Debian pool (since this seems the main
  development place for mmv).
- Added the copyright file from
  http://packages.debian.org/changelogs/pool/main/m/mmv/current/copyright
- Spec file updates:
  * Changed the License to GPL+ based on the copyright file.
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Updates in Summary: and %%description sections.
  * Added description for patches based on openSUSE Patches Guidelines.
  * Removed %%changelog entries from spec file.
  * bzip the source package.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 13 2005 anicka@suse.cz
- add LARGEFILE to CFLAGS (bug #137906)
* Tue Apr  5 2005 nadvornik@suse.cz
- fixed include files for gcc4
* Thu Mar  4 2004 tcrhak@suse.cz
- honor '--' in option list (bug #35289)
* Fri Jan 30 2004 mfabian@suse.de
- add patch from Bjoern Jacke <jacke@exsuse.de> to allow
  non-ASCII for the target file names (see Bugzilla #34232).
- use # norootforbuild.
* Wed Sep 25 2002 tcrhak@suse.cz
- in checkto(): assign fdel NULL if it is
  assigned no value so far (fixes bug #19924)
- linked dynamically
* Fri Apr 20 2001 cihlar@suse.cz
- use RPM_OPT_FLAGS
- fixed to compile on s390
* Tue Mar 20 2001 cihlar@suse.cz
- fix to compile on axp
* Wed Dec  6 2000 schwab@suse.de
- Fix to build on ia64.
* Thu Nov  9 2000 cihlar@suse.cz
- clean up spec file
- fixed copyrigt tag
* Wed May 17 2000 cihlar@suse.cz
- added BuildRoot
- Group sorted
* Fri May 12 2000 schwab@suse.de
- Fix Makefile for ia64.
* Tue Jan 25 2000 ro@suse.de
- man to /usr/share using macro
* Sun Dec 19 1999 kukuk@suse.de
- Fix Makefile for SPARC
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Aug 25 1999 uli@suse.de
- no m486 on PPC
* Tue Feb  2 1999 ro@suse.de
- no m486 on alpha
* Thu Jun 18 1998 ro@suse.de
- builds for libc5 and glibc
